@@ -54,7 +54,7 @@ def generate_actions_from_irc_message(args,printer):
                                            u"alert_message": alrt_msg,
                                            u"urgency": u"low"}} )
         if debug:
-            printer("Monitoring Channel Msg" + channel, str(monitored_channels))
+            printer("Monitoring Channel Msg" + channel, "channels: " + str(monitored_channels))
                     
     return actions_todo
 
@@ -74,18 +74,18 @@ def display_alert(args,printer):
     alert_title = args[u'alert_title']
     alert_message = args[u'alert_message']
     urgency = args[u'urgency']
-    # msg=Notify.Notification.new (alert_title, alert_message, u"dialog-information")
-    # msg.show ()
     cmd = construct_notification_command(alert_title, alert_message, urgency)
     #    pdb.set_trace()
-    # printer ("The Command:", str(cmd))
+    if debug: 
+        printer ("The Command:", str(cmd))
     call(cmd)    
     
 def play_sound(args,printer):
     a = 1
-    filename = u"~/bin/sounds/" + args[u'sound_file'] + u".ogg"    
-    cmd = [u"play", u"-q", filename]
-    # printer ("The Command:", str(cmd))
+    filename = "~/bin/sounds/" + args['sound_file'] + ".ogg"    
+    cmd = ["play", "-q", filename]
+    if debug: 
+        printer ("The Command:", str(cmd))
     call(cmd)
 
 
